
function I = integrale_trapezi_composta (f,a,b,m)

% Formula dei trapezi composta
%
% I = integrale_trapezi_composta (f,a,b,m);
%
% Dati di ingresso:
%  f: funzione integranda
%  a: estremo sinistro dell'intervallo di integrazione
%  b: estremo destro dell'intervallo di integrazione
%  m: numero di sottointervalli
% Dati di uscita:
%  I: approssimazione dell'integrale definito

[x,w]=trapezi_composta(m,a,b);
fx=feval(f,x);
I=w'*fx;



function [x,w]=trapezi_composta(N,a,b)

% FORMULA DEI TRAPEZI COMPOSTA.

% INPUT:
% N: NUMERO SUBINTERVALLI.
% a, b: ESTREMI DI INTEGRAZIONE.

% OUTPUT:
% x: NODI INTEGRAZIONE.
% w: PESI INTEGRAZIONE (INCLUDE IL PASSO!).

h=(b-a)/N;             % PASSO INTEGRAZIONE.
x=a:h:b; x=x';         % NODI INTEGRAZIONE.
w=ones(N+1,1);         % PESI INTEGRAZIONE.
w(1)=0.5; w(N+1)=0.5;
w=w*h;

